pub(crate) fn enqueue(cx: &JSContext, task: Box<dyn MicrotaskRunnable>)Expand description
Add a new microtask to this queue. It will be invoked as part of the next microtask checkpoint.
pub(crate) fn enqueue(cx: &JSContext, task: Box<dyn MicrotaskRunnable>)Add a new microtask to this queue. It will be invoked as part of the next microtask checkpoint.